let code_yes = 0o400
let min = 0o401
let break = 0o401
let down = 0o402
let up = 0o403
let left = 0o404
let right = 0o405
let home = 0o406
let backspace = 0o407
let f0 = 0o410
let dl = 0o510
let il = 0o511
let dc = 0o512
let ic = 0o513
let eic = 0o514
let clear = 0o515
let eos = 0o516
let eol = 0o517
let sf = 0o520
let sr = 0o521
let npage = 0o522
let ppage = 0o523
let stab = 0o524
let ctab = 0o525
let catab = 0o526
let enter = 0o527
let sreset = 0o530
let reset = 0o531
let print = 0o532
let ll = 0o533
let a1 = 0o534
let a3 = 0o535
let b2 = 0o536
let c1 = 0o537
let c3 = 0o540
let btab = 0o541
let beg = 0o542
let cancel = 0o543
let close = 0o544
let command = 0o545
let copy = 0o546
let create = 0o547
let end_ = 0o550
let exit = 0o551
let find = 0o552
let help = 0o553
let mark = 0o554
let message = 0o555
let move = 0o556
let next = 0o557
let open_ = 0o560
let options = 0o561
let previous = 0o562
let redo = 0o563
let reference = 0o564
let refresh = 0o565
let replace = 0o566
let restart = 0o567
let resume = 0o570
let save = 0o571
let sbeg = 0o572
let scancel = 0o573
let scommand = 0o574
let scopy = 0o575
let screate = 0o576
let sdc = 0o577
let sdl = 0o600
let select = 0o601
let send = 0o602
let seol = 0o603
let sexit = 0o604
let sfind = 0o605
let shelp = 0o606
let shome = 0o607
let sic = 0o610
let sleft = 0o611
let smessage = 0o612
let smove = 0o613
let snext = 0o614
let soptions = 0o615
let sprevious = 0o616
let sprint = 0o617
let sredo = 0o620
let sreplace = 0o621
let sright = 0o622
let srsume = 0o623
let ssave = 0o624
let ssuspend = 0o625
let sundo = 0o626
let suspend = 0o627
let undo = 0o630
let mouse = 0o631
let resize = 0o632
let max = 0o777
